@@ -1,4 +1,24 @@
+import random
 import re
+from typing import Type
+
+from django.db.models import Model
+from django.utils import timezone
+
+
+def generate_unique_data_id(model: Type[Model], field: str, prefix: str = None):
+    candidate = ""
+    date = timezone.now()
+    random_number = random.randint(10000, 99999)
+    not_unique = True
+    while not_unique:
+        candidate = f"{prefix or ''}{date.strftime('%y%m%d')}{random_number}"
+        filter_kwargs = {
+            field: candidate
+        }
+        if not model.objects.filter(**filter_kwargs).exists():
+            not_unique = False
+    return str(candidate)
 
 
 class ParseIdentityHyperlink:
