@@ -1,9 +1,14 @@
+import django
 from autoslug import AutoSlugField
 from django.db import models
 from django.utils import timezone
-from django.utils.translation import ugettext_lazy as _
 from gramedia.django.abstract_models import TimestampedModel
 
+if django.VERSION >= (4, 0):
+    from django.utils.translation import gettext_lazy as _
+else:
+    from django.utils.translation import ugettext_lazy as _
+
 
 class SoftDeleteModel(models.Model):
     is_active = models.BooleanField(_('active'), default=True)
@@ -21,7 +26,7 @@ class SoftDeleteModel(models.Model):
     def is_deleted(self):
         return True if self.deleted else False
 
-    def delete(self):
+    def delete(self, using=None, keep_parents=False):
         self.is_active = False
         self.deleted = timezone.now()
         self.save()
